
const gulp = require('gulp');
const concat = require('gulp-concat');
const autoprefixer = require('gulp-autoprefixer');
const cleanCSS = require('gulp-clean-css');
const uglify = require('gulp-uglify');
const del = require('del');
const browserSync = require('browser-sync').create();
const sass = require('gulp-sass');
const sourcemaps = require('gulp-sourcemaps');
const plumber = require('gulp-plumber');
const notify = require("gulp-notify");
const fileinclude = require('gulp-file-include');
const tiny = require('gulp-tinypng-nokey');
const svgmin = require('gulp-svgmin');
const cheerio = require('gulp-cheerio');
const svgSprite = require('gulp-svg-sprite');
const replace = require('gulp-replace');

function styles() {
   return gulp.src('./src/scss/style.scss')
   .pipe(plumber({errorHandler: notify.onError("Error: <%= error.message %>")}))
   .pipe(sass().on('error', sass.logError))
   .pipe(autoprefixer({
      browsers: ['last 2 versions'],
      cascade: false
   }))
   // .pipe(cleanCSS({
   //    level: 2
   // }))
   .pipe(gulp.dest('./build/css'))
   .pipe(browserSync.stream());
}
const jsFiles = [
   './node_modules/slick-carousel/slick/slick.min.js',
   './node_modules/aos/dist/aos.js',
   './node_modules/bootstrap/dist/js/bootstrap.min.js',
   './src/external/nstslider/src/jquery.nstSlider.js',
   './node_modules/magnific-popup/dist/jquery.magnific-popup.min.js',
   './src/external/perfect-scrollbar/perfect-scrollbar.min.js',
   './src/external/imagesloaded/imagesloaded.pkgd.min.js',
   './src/external/isotope/isotope.pkgd.min.js',
   './src/external/instafeed/instafeed.min.js',
   './src/external/jquery-nice-select/js/jquery.nice-select.min.js',
   './src/external/form/jquery.form.js',
   './src/external/form/jquery.validate.min.js',
   './src/external/form/jquery.form-init.js',
   './src/js/**/*.js'
];
function scripts() {
   return gulp.src(jsFiles,  { allowEmpty: true })
   .pipe(concat('bundle.js'))
   // .pipe(uglify({
   //    toplevel: true
   // }))
   .pipe(gulp.dest('./build/js'))
   .pipe(browserSync.stream());
}
function clean() {
   return del(['build/*'])
}
function html() {
   return gulp.src('./src/*.html')
   .pipe(plumber({errorHandler: notify.onError("Error: <%= error.message %>")}))
   .pipe(fileinclude({
      prefix: '@@',
      basepath: '@file'
    }))
   .pipe(gulp.dest('./build/'))
   .pipe(browserSync.stream());
}
function img() {
   return gulp.src('./src/images/**/*')
   // .pipe(tiny())
   .pipe(gulp.dest('./build/images/'))
   .pipe(browserSync.stream());
}
function svg(){
   return gulp.src('./src/includes/svg-sprite/item/*.svg')
   .pipe(svgmin({
      js2svg: {
          pretty: true
      }
  }))
  .pipe(cheerio({
   run: function ($) {
      // $('[fill]').removeAttr('fill');
      // $('[stroke]').removeAttr('stroke');
      // $('[style]').removeAttr('style');
   }
 }))
 .pipe(replace('&gt;', '>'))
 .pipe(svgSprite({
    mode:{
       symbol:{
          sprite:'../sprite.html'
       },
       view:{
         sprite:'../svg-view.svg'
      }
    }
 }))
 .pipe(gulp.dest('./src/includes/svg-sprite/'));
}
function watch() {
   browserSync.init({
      server: {
          baseDir: "./build/"
      }
  });
  gulp.watch('./src/scss/**/*.scss', styles)
  gulp.watch('./src/js/**/*.js', scripts)
  gulp.watch('./src/**/*.html', gulp.series(html)).on('change', browserSync.reload);
}

gulp.task('svg', svg);
gulp.task('styles', styles);
gulp.task('html', html);
gulp.task('scripts', scripts);
gulp.task('del', clean);
gulp.task('img', img);

gulp.task('watch', watch);
gulp.task('build', gulp.series(clean, gulp.parallel(styles,html,img,scripts)));
gulp.task('dev', gulp.series('build','watch'));